==> nextcloud-14.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/support/l10n/it.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Collegamento:",
    "Password:" : "Password:",
    "Generating system report failed." : "Generazione del report di sistema non riuscita.",
    "Subscription notifications" : "Notifiche di sottoscrizione",
    "Could not create folder \"System information\" to store generated report." : "Impossibile creare la cartella \"Informazioni di sistema\" per archiviare il report generato.",
    "Could not create file \"%s\" to store generated report." : "Impossibile creare il file \"%s\" per archiviare il report generato.",
    "Could not share file \"%s\"." : "Impossibile condividere il file \"%s\".",
    "Nextcloud Subscription" : "Sottoscrizioni di Nextcloud",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Il tuo server non ha una sottoscrizione di Nextcloud o la tua sottoscrizione è scaduta.",
    "Your Nextcloud server subscription does not cover your number of users." : "La sottoscrizione del tuo server Nextcloud non copre il numero di utenti.",
    "Your Nextcloud Subscription has expired!" : "La tua sottoscrizione di Nextcloud è scaduta!",
    "Your server has no Nextcloud Subscription or your Subscription has expired" : "Il tuo server non ha una sottoscrizione di Nextcloud o la tua sottoscrizione è scaduta",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Il tuo server Nextcloud non è supportato da una sottoscrizione aziendale di Nextcloud.",
    "A Nextcloud Support Subscription means the original developers behind your private cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "Una sottoscrizione di supporto di Nextcloud significa che gli sviluppatori originali dietro il server di cloud privato sono dedicati al 100% al tuo successo: la sicurezza, la scalabilità, le prestazioni e la funzionalità del tuo servizio!",
    "If you encounter a problem and your server does no longer work, blocking employees from sharing or customers from downloading and uploading files, you don't have to rely on searching online and asking volunteers on forums and social media for a solution. You have direct access to our experienced engineers who help you track down and fix the problem." : "Se si verifica un problema e il tuo server non funziona più, bloccando la condivisione tra gli impiegati o lo scaricamento o il caricamento dei file da parte dei clienti, non devi affidarti alle ricerche in linea o a chiedere una soluzione a volontari sui forum o sulle reti sociali. Hai accesso diretto ai nostri ingegneri esperti che ti aiuteranno a individuare e correggere il problema.",
    "You have a contract with the vendor providing confidential security information, mitigations, patches and updates." : "Hai un contratto con il venditore che fornisce informazioni di sicurezza confidenziali, mitigazioni, patch e aggiornamenti.",
    "If you want to skip a release or two and stay a bit longer on your current version without disruptions, you don't have to run software without security updates. We deliver them to you as long as is needed!" : "Se vuoi saltare un rilascio o due e rimanere per un po' con la tua versione attuale senza interruzioni, non devi eseguire software senza aggiornamenti di sicurezza. Ti consegneremo tali aggiornamenti fino a quando è necessario.",
    "If you have performance and scalability issues you have the best expertise at hand, instead of having to search on the web and hope you find a solution." : "Se hai problemi di prestazioni e scalabilità, hai le migliori esperienze a portata di mano, invece di dover cercare sul web e sperare di trovare una soluzione.",
    "If you are asked how the compliance of Nextcloud is and if you can deliver a data export under GDPR, HIPAA or other rules, you have access to the right documentation and can tap into our expertise to respond quickly and accurately." : "Se ti viene chiesto quale sia il livello di conformità di Nextcloud e se puoi consegnare un'esportazione di dati sotto GDPR, HIPAA o altre regolamentazioni, devi accedere alla giusta documentazione e puoi sfruttare la nostra esperienza per rispondere rapidamente e accuratamente.",
    "We can also provide you Outlook integration, Online Office, scalable integrated audio-video and chat communication an other features only available in a very limited form for free. And we can develop further integrations and capabilities you need." : "Possiamo inoltre fornirti integrazione con Outlook, Office online, comunicazioni audio-video e chat integrata scalabile e altre funzionalità disponibili solo in forma molto limitata gratuitamente. Possiamo sviluppare ulteriori integrazioni e capacità che potrebbero servirti.",
    "A subscription helps you get the most out of Nextcloud! Don't your users deserve the best?" : "Una sottoscrizione ti aiuta a ottenere il massimo da Nextcloud! Non pensi che i tuoi utenti meritino il meglio?",
    "Learn more now" : "Scopri altro subito",
    "Your Nextcloud server Subscription is over limit" : "La sottoscrizione del tuo server Nextcloud ha superato il limite",
    "Dear admin," : "Caro amministratore,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact you Nextcloud account manager to get your subscription updated!" : "La tua sottoscrizione Nextcloud non copre il numero di utenti che sono attualmente attivi su questo server. Contatta il tuo account manager di Nextcloud e aggiorna la tua sottoscrizione!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s è il tuo account manager e può essere raggiunto tramite email con %2$s o tramite telefono allo %3$s.",
    "Thank you," : "Grazie,",
    "Your Nextcloud team" : "La tua squadra di Nextcloud",
    "Your Nextcloud server Subscription is expired" : "La sottoscrizione del tuo server Nextcloud è scaduta.",
    "Your Nextcloud server Subscription is expired!" : "La sottoscrizione del tuo server Nextcloud è scaduta!",
    "Your Nextcloud Subscription has expired! Please contact you Nextcloud account manager to get your subscription updated!" : "La tua sottoscrizione di Nextcloud è scaduta! Contatta il tuo account manager di Nextcloud per aggiornare la tua sottoscrizione!",
    "Support" : "Supporto",
    "Getting support and help for your Nextcloud" : "Ottieni supporto e aiuto per il Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "L'applicazione di supporto ti fornisce accesso diretto al supporto e alle risorse di consultazione, opzioni di contatto dedicate con il tuo account manager e un riepilogo della tua sottoscrizione aziendale.",
    "Basic subscription" : "Sottoscrizione di base",
    "Standard subscription" : "Sottoscrizione standard",
    "Premium subscription" : "Sottoscrizione premium",
    "Géant subscription" : "Sottoscrizione gigante",
    "Silver partner subscription" : "Sottoscrizione partner argento",
    "Gold partner subscription" : "Sottoscrizione partner oro",
    "Subscription" : "Sottoscrizione",
    "Over subscription limit" : "Supera il limite della sottoscrizione",
    "Valid subscription" : "Sottoscrizione valida",
    "Expired subscription" : "Sottoscrizione scaduta",
    "Subscription key:" : "Chiave di sottoscrizione:",
    "_Expires in %n year_::_Expires in %n years_" : ["Scade tra %n anno","Scade tra %n anni"],
    "_Expires in %n month_::_Expires in %n months_" : ["Scade tra %n mese","Scade tra %n mesi"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["Scade tra %n settimana","Scade tra %n settimane"],
    "_Expires in %n day_::_Expires in %n days_" : ["Scade tra %n giorno","Scade tra %n giorni"],
    "_For %n users_::_For %n users_" : ["Per %n utenti","Per %n utenti"],
    "_currently at %n user_::_currently at %n users_" : ["attualmente a %n utente","attualmente a %n utenti"],
    "Includes support for %s" : "Include il supporto per %s",
    "Includes support for %1$s & %2$s" : "Include il supporto per %1$s e %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Include il supporto per %1$s, %2$s e %3$s",
    "Update subscription key" : "Aggiorna la chiave di sottoscrizione",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s è il tuo account manager. Non esitare a contattarlo se hai domande relative alla tua sottoscrizione.",
    "You can find answers to common question in our portal and also file support requests there." : "Puoi trovare risposte alle domande comuni nel nostro portale e creare richieste di supporto.",
    "Access Nextcloud portal" : "Accedi al portale di Nextcloud",
    "System information" : "Informazioni di sistema",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Raccogli le di sistema per le richieste di supporto. Il pulsante seguente genera un file di testo nella cartella \"Informazioni di sistema\" e lo condivide come un collegamento pubblico protetto da password. il collegamento è valido per 2 settimane.",
    "Generate system report" : "Genera report di sistema",
    "Enterprise subscription recommended" : "Sottoscrizione aziendale consigliata",
    "No active enterprise subscription" : "Nessuna sottoscrizione aziendale attiva",
    "Unsupported" : "Non supportato",
    "This Nextcloud server has no Enterprise Subscription." : "Questo server Nextcloud non ha alcuna sottoscrizione aziendale.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Una sottoscrizione aziendale di Nextcloud ti aiuta a ottenere il massimo da Nextcloud, tenere al sicuro i tuoi dati e far funzionare in modo affidabile il tuo server in qualsiasi momento.",
    "Advantages" : "Vantaggi",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Accedi all'esperienza tecnica degli sviluppatori di Nextcloud tramite documentazione e supporto",
    "Access to additional capabilities like Outlook integration, online office and more" : "Accesso a capacità aggiuntive come l'integrazione di Outlook, ufficio in linea e altro",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Accesso a esperienze e capacita di scalabilità per File e Talk",
    "Optional branding, consulting, architecture advice" : "Gestione facoltativa del marchio, consulenza, suggerimenti architetturali",
    "Confidential security notification service, mitigations, patches and advice" : "Servizio di notifica confidenziale sulla sicurezza, mitigazioni, patch e consulenza",
    "Compliance certification, advice and documentation" : "Certificazione di conformità, consulenza e documentazione",
    "Get a quote" : "Ottieni un preventivo",
    "More information" : "Altre informazioni",
    "Subscription benefits" : "Benefici della sottoscrizione",
    "Pricing" : "Prezzi",
    "Commmunity support" : "Supporto della comunità",
    "Forum" : "Forum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud è un software libero che è supportato da una comunità molto attiva. Registrati al forum per porre domande e discutere con altre persone.",
    "Nextcloud forum" : "Forum di Nextcloud",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud utilizza GitHub come piattaforma per lavorare in modo collaborativo. Puoi segnalare i bug direttamente lì.",
    "Nextcloud at GitHub" : "Nextcloud su GitHub",
    "Chat" : "Chat",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "Comunica in chat con noi sul nostro canale IRC #nextcloud su Freenide.",
    "Open chat" : "Apri chat",
    "Subscription key" : "Chiave di sottoscrizione",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Sei hai una sottoscrizione di Nextcloud attiva, digita qui la tua chiave di sottoscrizione.",
    "Learn more about an enterprise subscription." : "Scopri altro sulla sottoscrizione aziendale.",
    "Set subscription key" : "Imposta chiave di sottoscrizione",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Lle informazioni di sottoscrizione non possono essere recuperate correttamente in questo momento. Un nuovo tentativo è pianificato. Controlla più tardi.",
    "The subscription key was invalid." : "La chiave di sottoscrizione non era valida.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "La chiave di sottoscrizione non può essere verificata, poiché questo server non ha una connessione a Internet. Contatta la nostra squadra di supporto per risolvere il problema.",
    "The subscription key had an invalid format." : "La chiave di sottoscrizione avere un formato non valido.",
    "While fetching the subscription information an error happened." : "Si è verificato un errore durante il recupero delle informazioni di sottoscrizione.",
    "News" : "Novità",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Per essere aggiornati sulle novità di Nextcloud, iscriviti alla nostra newsletter e seguici sulle nostre reti sociali.",
    "Follow us on Google+" : "Seguici su Google+",
    "Like our Facebook page" : "Visita la nostra pagina di Facebook",
    "Follow us on Twitter" : "Seguici su Twitter",
    "Check out our blog" : "Leggi il nostro blog",
    "Subscribe to our newsletter" : "Iscriviti alla nostra newsletter"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/support/l10n/it.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Collegamento:",
    "Password:" : "Password:",
    "Generating system report failed." : "Generazione del report di sistema non riuscita.",
    "Subscription notifications" : "Notifiche di sottoscrizione",
    "Could not create folder \"System information\" to store generated report." : "Impossibile creare la cartella \"Informazioni di sistema\" per archiviare il report generato.",
    "Could not create file \"%s\" to store generated report." : "Impossibile creare il file \"%s\" per archiviare il report generato.",
    "Could not share file \"%s\"." : "Impossibile condividere il file \"%s\".",
    "Nextcloud Subscription" : "Sottoscrizioni di Nextcloud",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "Il tuo server non ha una sottoscrizione di Nextcloud o la tua sottoscrizione è scaduta.",
    "Your Nextcloud server subscription does not cover your number of users." : "La sottoscrizione del tuo server Nextcloud non copre il numero di utenti.",
    "Your Nextcloud Subscription has expired!" : "La tua sottoscrizione di Nextcloud è scaduta!",
    "Your server has no Nextcloud Subscription" : "Il tuo server non ha una sottoscrizione di Nextcloud",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "Il tuo server Nextcloud non è supportato da una sottoscrizione aziendale di Nextcloud.",
    "A Nextcloud Support Subscription means the original developers behind your private cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "Una sottoscrizione di supporto di Nextcloud significa che gli sviluppatori originali dietro il server di cloud privato sono dedicati al 100% al tuo successo: la sicurezza, la scalabilità, le prestazioni e la funzionalità del tuo servizio!",
    "If you encounter a problem and your server does no longer work, blocking employees from sharing or customers from downloading and uploading files, you don't have to rely on searching online and asking volunteers on forums and social media for a solution. You have direct access to our experienced engineers who help you track down and fix the problem." : "Se si verifica un problema e il tuo server non funziona più, bloccando la condivisione tra gli impiegati o lo scaricamento o il caricamento dei file da parte dei clienti, non devi affidarti alle ricerche in linea o a chiedere una soluzione a volontari sui forum o sulle reti sociali. Hai accesso diretto ai nostri ingegneri esperti che ti aiuteranno a individuare e correggere il problema.",
    "You have a contract with the vendor providing confidential security information, mitigations, patches and updates." : "Hai un contratto con il venditore che fornisce informazioni di sicurezza confidenziali, mitigazioni, patch e aggiornamenti.",
    "If you want to skip a release or two and stay a bit longer on your current version without disruptions, you don't have to run software without security updates. We deliver them to you as long as is needed!" : "Se vuoi saltare un rilascio o due e rimanere per un po' con la tua versione attuale senza interruzioni, non devi eseguire software senza aggiornamenti di sicurezza. Ti consegneremo tali aggiornamenti fino a quando è necessario.",
    "If you have performance and scalability issues you have the best expertise at hand, instead of having to search on the web and hope you find a solution." : "Se hai problemi di prestazioni e scalabilità, hai le migliori esperienze a portata di mano, invece di dover cercare sul web e sperare di trovare una soluzione.",
    "If you are asked how the compliance of Nextcloud is and if you can deliver a data export under GDPR, HIPAA or other rules, you have access to the right documentation and can tap into our expertise to respond quickly and accurately." : "Se ti viene chiesto quale sia il livello di conformità di Nextcloud e se puoi consegnare un'esportazione di dati sotto GDPR, HIPAA o altre regolamentazioni, devi accedere alla giusta documentazione e puoi sfruttare la nostra esperienza per rispondere rapidamente e accuratamente.",
    "We can also provide you Outlook integration, Online Office, scalable integrated audio-video and chat communication an other features only available in a very limited form for free. And we can develop further integrations and capabilities you need." : "Possiamo inoltre fornirti integrazione con Outlook, Office online, comunicazioni audio-video e chat integrata scalabile e altre funzionalità disponibili solo in forma molto limitata gratuitamente. Possiamo sviluppare ulteriori integrazioni e capacità che potrebbero servirti.",
    "A subscription helps you get the most out of Nextcloud! Don't your users deserve the best?" : "Una sottoscrizione ti aiuta a ottenere il massimo da Nextcloud! Non pensi che i tuoi utenti meritino il meglio?",
    "Learn more now" : "Scopri altro subito",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Questo messaggio è stato inviato a tutti gli amministratori dall'applicazione di supporto della tua istanza Nextcloud su %1$s poiché hai superato i %2$s utenti registrati.",
    "Your Nextcloud server Subscription is over limit" : "La sottoscrizione del tuo server Nextcloud ha superato il limite",
    "Dear admin," : "Caro amministratore,",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact you Nextcloud account manager to get your subscription updated!" : "La tua sottoscrizione Nextcloud non copre il numero di utenti che sono attualmente attivi su questo server. Contatta il tuo account manager di Nextcloud e aggiorna la tua sottoscrizione!",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s è il tuo account manager e può essere raggiunto tramite email con %2$s o tramite telefono allo %3$s.",
    "Thank you," : "Grazie,",
    "Your Nextcloud team" : "La tua squadra di Nextcloud",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than what your subscription covers." : "Questo messaggio è stato inviato a tutti gli amministratori dall'applicazione di supporto della tua istanza di Nextcloud su %s poiché hai più utenti di quanti ne copra la tua sottoscrizione.",
    "Your Nextcloud server Subscription is expired" : "La sottoscrizione del tuo server Nextcloud è scaduta.",
    "Your Nextcloud server Subscription is expired!" : "La sottoscrizione del tuo server Nextcloud è scaduta!",
    "Your Nextcloud Subscription has expired! Please contact you Nextcloud account manager to get your subscription updated!" : "La tua sottoscrizione di Nextcloud è scaduta! Contatta il tuo account manager di Nextcloud per aggiornare la tua sottoscrizione!",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Questo messaggio è stato inviato a tutti gli amministratori dall'applicazione di supporto della tua istanza di Nextcloud su %s poiché la tua sottoscrizione è scaduta.",
    "Support" : "Supporto",
    "Getting support and help for your Nextcloud" : "Ottieni supporto e aiuto per il Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "L'applicazione di supporto ti fornisce accesso diretto al supporto e alle risorse di consultazione, opzioni di contatto dedicate con il tuo account manager e un riepilogo della tua sottoscrizione aziendale.",
    "Basic subscription" : "Sottoscrizione di base",
    "Standard subscription" : "Sottoscrizione standard",
    "Premium subscription" : "Sottoscrizione premium",
    "Géant subscription" : "Sottoscrizione gigante",
    "Silver partner subscription" : "Sottoscrizione partner argento",
    "Gold partner subscription" : "Sottoscrizione partner oro",
    "Subscription" : "Sottoscrizione",
    "Over subscription limit" : "Supera il limite della sottoscrizione",
    "Valid subscription" : "Sottoscrizione valida",
    "Expired subscription" : "Sottoscrizione scaduta",
    "Subscription key:" : "Chiave di sottoscrizione:",
    "_Expires in %n year_::_Expires in %n years_" : ["Scade tra %n anno","Scade tra %n anni"],
    "_Expires in %n month_::_Expires in %n months_" : ["Scade tra %n mese","Scade tra %n mesi"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["Scade tra %n settimana","Scade tra %n settimane"],
    "_Expires in %n day_::_Expires in %n days_" : ["Scade tra %n giorno","Scade tra %n giorni"],
    "_For %n users_::_For %n users_" : ["Per %n utenti","Per %n utenti"],
    "_currently at %n user_::_currently at %n users_" : ["attualmente a %n utente","attualmente a %n utenti"],
    "Includes support for %s" : "Include il supporto per %s",
    "Includes support for %1$s & %2$s" : "Include il supporto per %1$s e %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Include il supporto per %1$s, %2$s e %3$s",
    "Update subscription key" : "Aggiorna la chiave di sottoscrizione",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s è il tuo account manager. Non esitare a contattarlo se hai domande relative alla tua sottoscrizione.",
    "You can find answers to common question in our portal and also file support requests there." : "Puoi trovare risposte alle domande comuni nel nostro portale e creare richieste di supporto.",
    "Access Nextcloud portal" : "Accedi al portale di Nextcloud",
    "System information" : "Informazioni di sistema",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Raccogli le di sistema per le richieste di supporto. Il pulsante seguente genera un file di testo nella cartella \"Informazioni di sistema\" e lo condivide come un collegamento pubblico protetto da password. il collegamento è valido per 2 settimane.",
    "Generate system report" : "Genera report di sistema",
    "Enterprise subscription recommended" : "Sottoscrizione aziendale consigliata",
    "No active enterprise subscription" : "Nessuna sottoscrizione aziendale attiva",
    "Unsupported" : "Non supportato",
    "This Nextcloud server has no Enterprise Subscription." : "Questo server Nextcloud non ha alcuna sottoscrizione aziendale.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Una sottoscrizione aziendale di Nextcloud ti aiuta a ottenere il massimo da Nextcloud, tenere al sicuro i tuoi dati e far funzionare in modo affidabile il tuo server in qualsiasi momento.",
    "Advantages" : "Vantaggi",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Accedi all'esperienza tecnica degli sviluppatori di Nextcloud tramite documentazione e supporto",
    "Access to additional capabilities like Outlook integration, online office and more" : "Accesso a capacità aggiuntive come l'integrazione di Outlook, ufficio in linea e altro",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Accesso a esperienze e capacita di scalabilità per File e Talk",
    "Optional branding, consulting, architecture advice" : "Gestione facoltativa del marchio, consulenza, suggerimenti architetturali",
    "Confidential security notification service, mitigations, patches and advice" : "Servizio di notifica confidenziale sulla sicurezza, mitigazioni, patch e consulenza",
    "Compliance certification, advice and documentation" : "Certificazione di conformità, consulenza e documentazione",
    "Get a quote" : "Ottieni un preventivo",
    "More information" : "Altre informazioni",
    "Subscription benefits" : "Benefici della sottoscrizione",
    "Pricing" : "Prezzi",
    "Commmunity support" : "Supporto della comunità",
    "Forum" : "Forum",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud è un software libero che è supportato da una comunità molto attiva. Registrati al forum per porre domande e discutere con altre persone.",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud utilizza GitHub come piattaforma per lavorare in modo collaborativo. Puoi segnalare i bug direttamente lì.",
    "Chat" : "Chat",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "Comunica in chat con noi sul nostro canale IRC #nextcloud su Freenide.",
    "Nextcloud forum" : "Forum di Nextcloud",
    "Nextcloud at GitHub" : "Nextcloud su GitHub",
    "Open chat" : "Apri chat",
    "Subscription key" : "Chiave di sottoscrizione",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Sei hai una sottoscrizione di Nextcloud attiva, digita qui la tua chiave di sottoscrizione.",
    "Learn more about an enterprise subscription." : "Scopri altro sulla sottoscrizione aziendale.",
    "Set subscription key" : "Imposta chiave di sottoscrizione",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Lle informazioni di sottoscrizione non possono essere recuperate correttamente in questo momento. Un nuovo tentativo è pianificato. Controlla più tardi.",
    "The subscription key was invalid." : "La chiave di sottoscrizione non era valida.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "La chiave di sottoscrizione non può essere verificata, poiché questo server non ha una connessione a Internet. Contatta la nostra squadra di supporto per risolvere il problema.",
    "The subscription key had an invalid format." : "La chiave di sottoscrizione avere un formato non valido.",
    "While fetching the subscription information an error happened." : "Si è verificato un errore durante il recupero delle informazioni di sottoscrizione.",
    "News" : "Novità",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Per essere aggiornati sulle novità di Nextcloud, iscriviti alla nostra newsletter e seguici sulle nostre reti sociali.",
    "Follow us on Google+" : "Seguici su Google+",
    "Like our Facebook page" : "Visita la nostra pagina di Facebook",
    "Follow us on Twitter" : "Seguici su Twitter",
    "Check out our blog" : "Leggi il nostro blog",
    "Subscribe to our newsletter" : "Iscriviti alla nostra newsletter"
},
"nplurals=2; plural=(n != 1);");
